@@ -35,8 +35,7 @@ pub fn as_bytes(val: &str) -> Result<Vec<u8>, Box<dyn Error>> {
 }
 
 pub fn as_list(val: &str) -> Result<Vec<String>, Box<dyn Error>> {
-    let (_first, last) = val.split_at(2);
-    let strings: Vec<&str> = last.split("0X").collect();
+    let strings: Vec<&str> = val.split("0X").collect();
     let res = strings.iter().map(|x| x.to_string()).collect();
     Ok(res)
 }
