@@ -26,7 +26,7 @@ pub fn bytes(val: &Vec<u8>) -> String {
 }
 
 pub fn list(val: &Vec<String>) -> String {
-    let mut res: String = String::from("0X");
+    let mut res: String = String::new();
     val.iter().for_each(|x| res.push_str(x));
     res
 }
